package models

import (
	"database/sql"
	commonLog "doc-service/common/log"
	"fmt"
	"gopkg.in/ini.v1"
	"os"
	"time"
)
import _ "github.com/go-sql-driver/mysql"

var MysqlDB *sql.DB

func init() {
	var mysqlErr error

	config, iniErr := ini.Load("./conf/app.ini")
	if iniErr != nil {
		commonLog.Error("读取配置文件出错%s", iniErr)
		os.Exit(1)
	}

	ip := config.Section("mysql").Key("ip").String()
	port := config.Section("mysql").Key("port").String()
	user := config.Section("mysql").Key("user").String()
	password := config.Section("mysql").Key("password").String()
	database := config.Section("mysql").Key("database").String()
	dsn := fmt.Sprintf("%s:%s@tcp(%s:%s)/%s?charset=utf8mb4&parseTime=True&loc=Local", user, password, ip, port, database)

	MysqlDB, mysqlErr = sql.Open("mysql", dsn)

	if nil != mysqlErr {
		panic(mysqlErr)
	}

	MysqlDB.SetMaxOpenConns(128)
	MysqlDB.SetMaxIdleConns(16)
	MysqlDB.SetConnMaxLifetime(2 * time.Minute)

	if mysqlErr = MysqlDB.Ping(); nil != mysqlErr {
		panic(mysqlErr)
	}
}
